@@ -1,4 +1,4 @@
 from __future__ import absolute_import
-from .zjw1 import *
+from .tools import *
 
 name = "zjw"
\ No newline at end of file
